summaryrefslogtreecommitdiff
path: root/jstests/auth/lib/commands_lib.js
diff options
context:
space:
mode:
authorliubov.molchanova <liubov.molchanova@mongodb.com>2023-05-17 08:16:48 +0000
committerEvergreen Agent <no-reply@evergreen.mongodb.com>2023-05-17 10:20:42 +0000
commit87160f876c6fb94f5d03062b2caee57539ec5d8e (patch)
treeb78d9ca9e853a236e0a2f6432a6ac02dc50119cd /jstests/auth/lib/commands_lib.js
parent1c390a0c50104a04cbd8ecbefb99eaf22e1bc914 (diff)
downloadmongo-87160f876c6fb94f5d03062b2caee57539ec5d8e.tar.gz
Revert "SERVER-76427: Rename $telemetry to $queryStats"
This reverts commit d646e44b7801a3e5b3230bbae7dcfe05a5ed8707.
Diffstat (limited to 'jstests/auth/lib/commands_lib.js')
-rw-r--r--jstests/auth/lib/commands_lib.js6
1 files changed, 3 insertions, 3 deletions
diff --git a/jstests/auth/lib/commands_lib.js b/jstests/auth/lib/commands_lib.js
index 1d60c7aa308..170223762b4 100644
--- a/jstests/auth/lib/commands_lib.js
+++ b/jstests/auth/lib/commands_lib.js
@@ -6629,12 +6629,12 @@ export const authCommandsLib = {
]
},
{
// Test that only clusterManager has permission to run $queryStats
testname: "testTelemetryReadPrivilege",
- command: {aggregate: 1, pipeline: [{$queryStats: {}}], cursor: {}},
+ command: {aggregate: 1, pipeline: [{$telemetry: {}}], cursor: {}},
skipSharded: false,
skipTest: (conn) => {
- return !TestData.setParameters.featureFlagQueryStats;
+ return !TestData.setParameters.featureFlagTelemetry;
},
testcases: [{runOnDb: adminDbName, roles: roles_clusterManager}]
},
@@ -6629,12 +6629,12 @@ export const authCommandsLib = {
},
{
- // Test that only clusterManager has permission to run $queryStats
+ // Test that only clusterManager has permission to run $telemetry
testname: "testTelemetryReadPrivilege",